function pt = peaktrough(ll,aaa, thr, ddthr)
% PEAKTROUGH - Find peaks and troughs in a sequence of curves
%    pt = PEAKTROUGH(ll, aaa, thr, ddthr)
[K N]=size(aaa);
M=8;
dl=mean(diff(ll));

pkloc = zeros(N,M) + nan;
pkamp = zeros(N,M) + nan;
pkintg = zeros(N,M) + nan;
pktyp = zeros(N,M) + nan;
pkstart = zeros(N,M) + nan;
pkend = zeros(N,M) + nan;

trloc = zeros(N,M) + nan;
tramp = zeros(N,M) + nan;
trintg = zeros(N,M) + nan;
trtyp = zeros(N,M) + nan;
trstart = zeros(N,M) + nan;
trend = zeros(N,M) + nan;

pks=0;
trs=0;

for n=1:N
  aa = aaa(:,n);
  
  %%%%%%%% peaks %%%%%%%%
  [iup,idn,iu_,id_] = schmitt2(aa,0,-thr);
  L=length(iup);
  locs=zeros(L,1);
  for l=1:L
    [am,idx] = max(aa(iup(l):idn(l)));
    locs(l) = ll(idx+iup(l)-1);
  end
  for l=1:L
    [am,idx] = max(aa(iup(l):idn(l)));
    lo = ll(idx + iup(l)-1);
    if n==1
      m=l;
    else
      [dd,m]=min(abs(lo-pkloc(n-1,:)));
      [dd_,l_] = min(abs(locs - pkloc(n-1,m)));
      if dd>ddthr | dd_<dd
        m=pks+1;
      end
    end
    pks=max(pks,m);
    pkloc(n,m) = lo;
    pkamp(n,m) = am;
    if iup(l)==1
      pktyp(n,m)=-1;
    elseif idn(l)==length(ll)
      pktyp(n,m)=1;
    else
      pktyp(n,m)=0;
    end
    
    pkintg(n,m) = sum(aa(iup(l):idn(l)))*dl;
    pkend(n,m) = ll(idn(l));
    pkstart(n,m) = ll(iup(l));
  end
  
  %%%%%%%%%%% troughs %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  aa=-aa;
  [iup,idn,iu_,id_] = schmitt2(aa,0,-thr);
  L=length(iup);
  locs=zeros(L,1);
  for l=1:L
    [am,idx] = max(aa(iup(l):idn(l)));
    locs(l) = ll(idx+iup(l)-1);
  end
  for l=1:L
    [am,idx] = max(aa(iup(l):idn(l)));
    lo = ll(idx + iup(l)-1);
    if n==1
      m=l;
    else
      [dd,m]=min(abs(lo-trloc(n-1,:)));
      [dd_,l_] = min(abs(locs - trloc(n-1,m)));
      if dd>ddthr | dd_<dd
        m=trs+1;
      end
    end
    trs=max(trs,m);
    trloc(n,m) = lo;
    tramp(n,m) = am;
    if iup(l)==1
      trtyp(n,m)=-1;
    elseif idn(l)==length(ll)
      trtyp(n,m)=1;
    else
      trtyp(n,m)=0;
    end
    
    trintg(n,m) = sum(aa(iup(l):idn(l)))*dl;
    trend(n,m) = ll(idn(l));
    trstart(n,m) = ll(iup(l));
  end
end


pt.pkloc = pkloc;
pt.pkamp = pkamp;
pt.pkintg = pkintg;
pt.pktyp = pktyp;
pt.pkstart = pkstart;
pt.pkend = pkend;

pt.trloc = trloc;
pt.tramp = tramp;
pt.trintg = trintg;
pt.trtyp = trtyp;
pt.trstart = trstart;
pt.trend = trend;
